==> v0.2.1.tar.gz: cambridge/README.md <==
![Cambridge Banner](https://cdn.discordapp.com/attachments/764432435802013709/767724895076614154/cambridge_logo_lt.png)

Cambridge
=========

Welcome to Cambridge, the next open-source falling-block game engine!

This fork is written and maintained exclusively by [SashLilac](https://github.com/SashLilac), [joezeng](https://github.com/joezeng) and [Oshisaure](https://github.com/oshisaure)!

Join our Discord server for help and a welcoming community! https://discord.gg/mteMJw4

Credits
-------

- [Lilla Oshisaure](https://www.youtube.com/user/LeSpyroshisaure) for being my co-dev!
- [joezeng](https://github.com/joezeng) for the original project, and for offering to help with the expansion!
- [The Tetra Legends Discord](http://discord.com/invite/7hMx5r2) for supporting me and playtesting!
- [The Absolute Plus](https://discord.gg/6Gf2awJ) for being another source of motivation!

The following people in no particular order also helped with the project:
- [Hailey](https://github.com/haileylgbt)
- CylinderKnot
- MarkGamed7794
- [Mizu](https://github.com/rexxt)
- MattMayuga
- Kitaru
- switchpalacecorner
- [sinefuse](https://github.com/sinefuse)
- [2Tie](https://github.com/2Tie)
- [nightmareci](https://github.com/nightmareci)

![Cambridge Logo](https://cdn.discordapp.com/attachments/625496179433668635/763363717730664458/Icon_2.png)

Playing the game
----------------

### macOS, Linux

If you haven't already, install `love` with your favourite package manager (Homebrew on macOS, your system's default on Linux). **Make sure you're using LÖVE 11, because it won't work with earlier versions!**

Clone the repository in git:

	git clone https://github.com/SashLilac/cambridge

Alternatively, download the source code ZIP in the latest release.

Then, navigate to the root directory that you just cloned, and type:

	love .

It should run automatically!

### Windows

You do not need LÖVE on Windows, as it comes bundled with the program. Download the source code ZIP in the latest release, or if you want the bleeding edge version, download [this](https://github.com/SashLilac/cambridge/archive/master.zip).

Extract the ZIP, open a Command Prompt at the folder you extracted Cambridge to, then run this command:

	dist\windows\love.exe .

Alternatively, if you're on a 32-bit system, run this instead:

	dist\win32\love.exe .

32-bit systems do not support rich presence integration.

## Installing modpacks

Simply drag your mode, ruleset, and randomizer Lua files into their respective directory, and they should appear automatically.  

Alternatively, install [this](https://files.catbox.moe/66td2i.zip) mod pack to get a taste of the mod potential.

License
-------

The Cambridge project is licensed under the MIT license (included in LICENSE.md).

Some code and assets in this repository are contributed by members of the
community, as well as borrowed from other places, either with licensing
or as placeholders until suitable material can be found that is properly
licensed. Their original sources, and copyright notices if applicable, are
listed in the file SOURCES.

==> v0.2.1.1.tar.gz: cambridge/README.md <==
![Cambridge Banner](https://cdn.discordapp.com/attachments/764432435802013709/767724895076614154/cambridge_logo_lt.png)

Cambridge
=========

Welcome to Cambridge, the next open-source falling-block game engine!

This fork is written and maintained exclusively by [SashLilac](https://github.com/SashLilac), [joezeng](https://github.com/joezeng) and [Oshisaure](https://github.com/oshisaure)!

Join our Discord server for help and a welcoming community! https://discord.gg/mteMJw4

Credits
-------

- [Lilla Oshisaure](https://www.youtube.com/user/LeSpyroshisaure) for being my co-dev!
- [joezeng](https://github.com/joezeng) for the original project, and for offering to help with the expansion!
- [The Tetra Legends Discord](http://discord.com/invite/7hMx5r2) for supporting me and playtesting!
- [The Absolute Plus](https://discord.gg/6Gf2awJ) for being another source of motivation!

The following people in no particular order also helped with the project:
- [Hailey](https://github.com/haileylgbt)
- CylinderKnot
- MarkGamed7794
- [Mizu](https://github.com/rexxt)
- MattMayuga
- Kitaru
- switchpalacecorner
- [sinefuse](https://github.com/sinefuse)
- [2Tie](https://github.com/2Tie)
- [nightmareci](https://github.com/nightmareci)
- [MyPasswordIsWeak](https://github.com/MyPasswordIsWeak)

![Cambridge Logo](https://cdn.discordapp.com/attachments/625496179433668635/763363717730664458/Icon_2.png)

Playing the game
----------------

### Windows

You do not need LÖVE on Windows, as it comes bundled with the program.  

To get the stable release, simply download the ZIP in the latest release. All assets needed are bundled with the executable.

If you want the bleeding edge version, or want mod pack support, download [this](https://github.com/SashLilac/cambridge/archive/master.zip).

Extract the ZIP, open a Command Prompt at the folder you extracted Cambridge to, then run this command:

	dist\windows\love.exe .

Alternatively, if you're on a 32-bit system, run this instead:

	dist\win32\love.exe .

32-bit systems do not support rich presence integration.

Then, check the mod pack section at the bottom of this page.

### macOS, Linux

If you haven't already, install `love` with your favourite package manager (Homebrew on macOS, your system's default on Linux). **Make sure you're using LÖVE 11, because it won't work with earlier versions!**

Clone the repository in git:

	git clone https://github.com/SashLilac/cambridge

Alternatively, download the source code ZIP in the latest release.

Then, navigate to the root directory that you just cloned, and type:

	love .

It should run automatically!

## Installing modpacks

Simply drag your mode, ruleset, and randomizer Lua files into their respective directory, and they should appear automatically.  

Alternatively, install [this](https://github.com/SashLilac/cambridge-modpack) mod pack to get a taste of the mod potential.

License
-------

The Cambridge project is licensed under the MIT license (included in LICENSE.md).

Some code and assets in this repository are contributed by members of the
community, as well as borrowed from other places, either with licensing
or as placeholders until suitable material can be found that is properly
licensed. Their original sources, and copyright notices if applicable, are
listed in the file SOURCES.
